Libreria creada ARA LA MATERIA DE Cálculo Numérico para Desarrollo de Aplicaciones, esta libreria busca resolver de manera breve y de forma facil sistemas de ecuaciones lineales y no lineales utilizando los siguientes metodos de resolución:


    Eliminación de Gauss
    Gauss-Jordan
    Crammer
    Descomposición LU
    Jacobi
    Gauss-Seidel
    Bisección